@@ -1,16 +1,16 @@
-from .types import ModuleAware
-from .public import public
 from .private import private
+from .public import public
+from .types import ModuleAware
 
 
-__version__ = '2.0'
+__version__ = '2.1'
 
 
-def install():
+def install() -> None:
     """Install @public and @private into builtins."""
     import builtins
-    builtins.public = public
-    builtins.private = private
+    builtins.public = public            # type: ignore [attr-defined]
+    builtins.private = private          # type: ignore [attr-defined]
 
 
 public(
